* doc/mainpage.dox: Here.
* scribo/preprocessing/rotate_90.hh:
Replace extended characters to convert to plain ASCII.
Typos.
* doc/Doxyfile.in (INPUT_ENCODING): Set to UTF-8.
---
scribo/ChangeLog | 10 ++++++++++
scribo/doc/Doxyfile.in | 2 +-
scribo/doc/mainpage.dox | 4 ++--
scribo/scribo/preprocessing/rotate_90.hh | 14 +++++++-------
4 files changed, 20 insertions(+), 10 deletions(-)
diff --git a/scribo/ChangeLog b/scribo/ChangeLog
index 3a157ef..2e4bc02 100644
--- a/scribo/ChangeLog
+++ b/scribo/ChangeLog
@@ -1,3 +1,13 @@
+2014-06-25 Roland Levillain <roland(a)lrde.epita.fr>
+
+ Convert Scribo to UTF-8.
+
+ * doc/mainpage.dox: Here.
+ * scribo/preprocessing/rotate_90.hh:
+ Replace extended characters to convert to plain ASCII.
+ Typos.
+ * doc/Doxyfile.in (INPUT_ENCODING): Set to UTF-8.
+
2013-04-18 Guillaume Lazzara <z(a)lrde.epita.fr>
* demo/xml2doc/main.cc: Add --template-path option.
diff --git a/scribo/doc/Doxyfile.in b/scribo/doc/Doxyfile.in
index d37780e..6b1754b 100644
--- a/scribo/doc/Doxyfile.in
+++ b/scribo/doc/Doxyfile.in
@@ -126,7 +126,7 @@ IMAGE_PATH = @top_srcdir@/scribo/doc/images \
INPUT_FILTER =
FILTER_PATTERNS =
FILTER_SOURCE_FILES = NO
-INPUT_ENCODING = ISO-8859-1
+INPUT_ENCODING = UTF-8
CITE_BIB_FILES = @abs_top_srcdir@/doc/doc.bib \
@abs_top_srcdir@/doc/olena.bib
LATEX_BIB_STYLE = plain
diff --git a/scribo/doc/mainpage.dox b/scribo/doc/mainpage.dox
index 77786d9..4fa4014 100644
--- a/scribo/doc/mainpage.dox
+++ b/scribo/doc/mainpage.dox
@@ -6,9 +6,9 @@ Scribo, a framework for Document Image Analysis.
Its initial release has been developed in the context of the SCRIBO
project of the Free Software Thematic Group, part of the "Systematic
-Paris-R�gion" Cluster (France). This project was partially funded by
+Paris-Région" Cluster (France). This project was partially funded by
the French government, its economic development agencies and by the
-Paris-R�gion institutions.
+Paris-Région institutions.
It aims at providing the following features:
diff --git a/scribo/scribo/preprocessing/rotate_90.hh
b/scribo/scribo/preprocessing/rotate_90.hh
index af2958e..019fa12 100644
--- a/scribo/scribo/preprocessing/rotate_90.hh
+++ b/scribo/scribo/preprocessing/rotate_90.hh
@@ -1,5 +1,5 @@
-// Copyright (C) 2010, 2011 EPITA Research and Development Laboratory
-// (LRDE)
+// Copyright (C) 2010, 2011, 2014 EPITA Research and Development
+// Laboratory (LRDE).
//
// This file is part of Olena.
//
@@ -29,7 +29,7 @@
/// \file
///
/// Fast +90/-90 degrees rotation.
# include <mln/core/concept/image.hh>
@@ -48,11 +48,11 @@ namespace scribo
using namespace mln;
/*! \brief Perform a +90/-90 degrees rotation.
\param[in] input An image.
- \param[in] positive If set to true, performs a +90� rotation,
- -90� otherwise.
+ \param[in] positive If set to true, performs a +90 degree rotation,
+ -90 degree otherwise.
\return A rotated image.
*/
@@ -60,7 +60,7 @@ namespace scribo
mln_concrete(I)
rotate_90(const Image<I>& input, bool positive);
- /// \brief Performs a +90� rotation.
+ /// \brief Performs a +90 degree rotation.
/// \overload
//
template <typename I>
@@ -29,7 +29,7 @@
/// \file
///
-/// Fast +90/-90 degrees rotation.
+/// Fast +90/-90 degree rotation.
# include <mln/core/concept/image.hh>
@@ -48,11 +48,11 @@ namespace scribo
using namespace mln;
- /*! \brief Perform a +90/-90 degrees rotation.
+ /*! \brief Perform a +90/-90 degree rotation.
\param[in] input An image.
--
1.7.10.4
Show replies by date